import React, { useState, useRef } from 'react';
import PropTypes from 'prop-types';
import { Trans } from '@cloudflare/intl-react';
import { Textarea as UnstyledTextarea } from '@cloudflare/component-textarea';
import { createComponent, createStyledComponent } from '@cloudflare/style-container';
var Textarea = createComponent(_ref => {
  var {
    theme
  } = _ref;
  return {
    height: '7rem',
    wordBreak: 'break-all',
    cursor: 'text',
    resize: 'none',
    color: theme.colors.gray[1],
    fontFamily: 'monaco, courier, monospace'
  };
}, UnstyledTextarea);

var styles = () => ({
  mt: 3,
  cursor: 'pointer'
});

var HelpText = createComponent(_ref2 => {
  var {
    theme
  } = _ref2;
  return {
    fontSize: theme.fontSizes[2],
    color: theme.colors.gray[2],
    marginTop: theme.space[2],
    marginBottom: theme.space[3]
  };
}, 'p');

var CopyableTextarea = _ref3 => {
  var {
    name,
    value = '',
    onCopy,
    className,
    clickToCopyText = 'Click here to copy',
    copiedTextToClipboardText = 'Copied text to clipboard',
    pressCommandOrCtrlCToCopyText = 'Press Command/Ctrl+C to copy',
    clickToCopyTextId = 'common.click_to_copy',
    copiedTextToClipboardTextId = 'common.copied_to_clipboard',
    pressCommandOrCtrlCToCopyTextId = 'common.copy_failed'
  } = _ref3;
  var [copyState, setCopyState] = useState('init');
  var textarea = useRef(null);
  var helpTextId = {
    init: clickToCopyTextId,
    successed: copiedTextToClipboardTextId,
    failed: pressCommandOrCtrlCToCopyTextId
  };
  var fallbackHelpText = {
    init: clickToCopyText,
    successed: copiedTextToClipboardText,
    failed: pressCommandOrCtrlCToCopyText
  };

  var handleFocus = () => {
    textarea.current && textarea.current.select();
    var success = false;

    try {
      success = document.execCommand('copy');
    } catch (err) {
      success = false;
    }

    if (success && onCopy) {
      onCopy();
    }

    setCopyState(success ? 'successed' : 'failed');
  };

  var handleBlur = () => {
    setCopyState('init');
  };

  return /*#__PURE__*/React.createElement("div", {
    className: className
  }, /*#__PURE__*/React.createElement(Textarea, {
    innerRef: textarea,
    readOnly: true,
    name: name,
    value: value,
    onFocus: handleFocus,
    onBlur: handleBlur
  }), /*#__PURE__*/React.createElement(HelpText, {
    onClick: handleFocus
  }, /*#__PURE__*/React.createElement(Trans, {
    id: helpTextId[copyState],
    _: fallbackHelpText[copyState]
  })));
};

CopyableTextarea.propTypes = {
  className: PropTypes.string,
  name: PropTypes.string.isRequired,
  value: PropTypes.string.isRequired,
  onCopy: PropTypes.func,
  clickToCopyText: PropTypes.string,
  copiedTextToClipboardText: PropTypes.string,
  pressCommandOrCtrlCToCopyText: PropTypes.string,
  clickToCopyTextId: PropTypes.string,
  copiedTextToClipboardTextId: PropTypes.string,
  pressCommandOrCtrlCToCopyTextId: PropTypes.string
};
CopyableTextarea.displayName = 'CopyableTextare';
export default createStyledComponent(styles, CopyableTextarea);